@@ -18,6 +18,7 @@ import time
 from typing import Union, Optional, List, Any
 
 from .i2c import SupMCUMaster
+from .serial import SupMCUSerialMaster
 from .parsing import parse_telemetry, _format_to_length
 from .types import SupMCUTelemetryDefinition, SupMCUModuleDefinition, TelemetryType, \
     _supmcu_fmt_data_type, _data_type_sizes, TelemetryDataItem
@@ -98,12 +99,19 @@ def get_values(i2c_master: I2CMaster, address: int, module_cmd_name: str, idx: i
     return vals.items
 
 
-def set_values(i2c_master: I2CMaster, address: int, module_cmd_name: str, idx: int, items: List[TelemetryDataItem], response_delay: Optional[float] = None):
+def set_values(master: Union[I2CMaster, SupMCUMaster, SupMCUSerialMaster],
+               address: int, module_cmd_name: str, idx: int, items: List[TelemetryDataItem],
+               response_delay: Optional[float] = None):
     if response_delay is None:
         # None was set by the SupMCU master or the passed in variable.
         response_delay = _DEFAULT_RESPONSE_DELAY
     values = ','.join((item.string_value for item in items))
-    i2c_master.write(address, f'{module_cmd_name}:TEL {idx},{values}\n'.encode('ascii'))
+    if isinstance(master, I2CMaster):
+        master.write(address, f'{module_cmd_name}:TEL {idx},{values}\n'.encode('ascii'))
+    elif isinstance(master, SupMCUMaster):
+        master.i2c_master.write(address, f'{module_cmd_name}:TEL {idx},{values}\n'.encode('ascii'))
+    elif isinstance(master, SupMCUSerialMaster):
+        master.send_command(module_cmd_name, f'{module_cmd_name}:TEL {idx},{values}\n')
 
 
 def request_telemetry_definition(i2c_master: Union[I2CMaster, SupMCUMaster],
