@@ -108,8 +108,8 @@ class _StringParser(DataItemParser):
         """
         try:
             null_term_pos = b.index(0)
-        except ValueError:
-            raise ValueError("`b` does not contain a null-terminated string")
+        except ValueError as e:
+            raise ValueError("`b` does not contain a null-terminated string") from e
         parse_bytes = b[:null_term_pos]
         left = b[null_term_pos + 1:]  # Everything AFTER the null terminator
 
